==> qtjambi-svg-debuginfo-macos-6.5.6.jar: sources/QtJambiSvg/QSvgRenderer_shell.h <==
#ifndef QSVGRENDERER_SHELL_H
#define QSVGRENDERER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSvg/qsvgrenderer.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qxmlstream.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtransform.h>
#include <QtJambi/RegistryAPI>


class QSvgRenderer_shell : public QSvgRenderer, public QtJambiShellInterface
{
public:
    QSvgRenderer_shell(const QByteArray& contents0, QObject* parent1 = nullptr);
    QSvgRenderer_shell(QObject* parent0 = nullptr);
    QSvgRenderer_shell(const QString& filename0, QObject* parent1 = nullptr);
    QSvgRenderer_shell(QXmlStreamReader* contents0, QObject* parent1 = nullptr);
    ~QSvgRenderer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSvgRenderer_access : public QSvgRenderer
{
};

#endif // QSVGRENDERER_SHELL_H

==> qtjambi-svg-debuginfo-macos-6.5.7.jar: sources/QtJambiSvg/QSvgRenderer_shell.h <==
#ifndef QSVGRENDERER_SHELL_H
#define QSVGRENDERER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSvg/qsvgrenderer.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qxmlstream.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtransform.h>
#include <QtJambi/RegistryAPI>


class QSvgRenderer_shell : public QSvgRenderer, public QtJambiShellInterface
{
public:
    QSvgRenderer_shell(const QByteArray& contents0, QObject* parent1 = nullptr);
    QSvgRenderer_shell(QObject* parent0 = nullptr);
    QSvgRenderer_shell(const QString& filename0, QObject* parent1 = nullptr);
    QSvgRenderer_shell(QXmlStreamReader* contents0, QObject* parent1 = nullptr);
    ~QSvgRenderer_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QSvgRenderer_mshell;
    friend class QSvgRenderer_oshell;
};


class QSvgRenderer_mshell : public QSvgRenderer_shell
{
public:
    using QSvgRenderer_shell::QSvgRenderer_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QSvgRenderer_oshell : public QSvgRenderer_mshell
{
public:
    using QSvgRenderer_mshell::QSvgRenderer_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSvgRenderer_access : public QSvgRenderer
{
};

#endif // QSVGRENDERER_SHELL_H
